======================================
Package Api Documentation for mlconjug
======================================


API Reference for the classes in mlconjug.mlconjug.py
-----------------------------------------------------

.. automodule:: mlconjug.mlconjug
    :member-order: bysource
    :members:
    :inherited-members:
    :show-inheritance:


API Reference for the classes in mlconjug.PyVerbiste.py
-------------------------------------------------------

.. automodule:: mlconjug.PyVerbiste
    :member-order: bysource
    :members:
